@@ -9,9 +9,9 @@
 
 
  cat("\n FactoClass: Combination of Factorial Methods and Cluster Analysis")
- cat("\n Universidad Nacional de Colombia")
- cat("\n Programed by: Pedro Cesar del Campo <pcdelcampon@unal.edu.co>")
- cat("\n               Campo Elias Pardo <cepardot@unal.edu.co> "      )    
+ cat("\n Universidad Nacional de Colombia Bogota. Departamento de Estadistica")
+ cat("\n Programed by: Campo Elias Pardo <cepardot@unal.edu.co> ")
+ cat("\n               Pedro Cesar del Campo <pcdelcampon@unal.edu.co>")    
   cat("\n With the contribution of:"      )
  cat("\n               Ivan Diaz <ildiazm@unal.edu.co>  ")
  cat("\n               Mauricio Sadinle <msadinleg@unal.edu.co>") 
